---
name: Question
about: Ask a question about synphot that is neither a bug report nor a feature request.
labels: 'question'
---

<!-- This comments are hidden when you submit the issue,
so you do not need to remove them! -->

<!-- Please be sure to check out our code of conduct,
https://github.com/spacetelescope/synphot_refactor/blob/master/CODE_OF_CONDUCT.md . -->

<!-- Please have a search on our GitHub repository to see if a similar
issue has already been posted.
If a similar issue is closed, have a quick look to see if you are satisfied
by the resolution.
If not please go ahead and open an issue! -->

<!-- If your question is HST specific, please stop and send a help call
to STScI via https://hsthelp.stsci.edu -->

<!-- If you question is JWST specific, please stop and send a help call
to STScI via https://jwsthelp.stsci.edu -->

### Description
<!-- Ask your question here. -->

### System Details (optional)
<!-- If you attempted to run synphot, please run the following snippet and paste the output below:
import platform; print(platform.platform())
import sys; print("Python", sys.version)
import numpy; print("Numpy", numpy.__version__)
import astropy; print("astropy", astropy.__version__)
import scipy; print("Scipy", scipy.__version__)
import matplotlib; print("Matplotlib", matplotlib.__version__)
import synphot; print("Synphot", synphot.__version__)
-->
